@@ -25,7 +25,7 @@ class DIR(object):
 
   def value(self):
     from hydrat import config
-    search_paths = [ config.getpath('paths','corpora') , '~']
+    search_paths = [ config.getpath('paths','corpora') , '.', '~']
     return find_dir(self.dirname, search_paths)
 
 class EXE(object):
@@ -120,12 +120,8 @@ def default_configuration():
   default_config = HydratConfigParser()
 
   default_config.add_section('paths')
-  default_config.set('paths', 'work', './work')
   default_config.set('paths', 'scratch', '/tmp')
-  default_config.set('paths', 'models', '%(work)s/models')
-  default_config.set('paths', 'tasks', '%(work)s/tasks')
-  default_config.set('paths', 'results', '%(work)s/results')
-  default_config.set('paths', 'output', '%(work)s/output')
+  default_config.set('paths', 'output', './output')
   default_config.set('paths', 'corpora', '~/data')
 
   default_config.add_section('tools')
